# -*- coding: utf-8 -*-
import pytest
import os
import heimdall
from .util import *


EMPTY_DUMP = f'''-- SQL dump, from a HERA database, using pyHeimdall
-- ------------------------------------------------------
-- pyHeimdall version	{heimdall.__version__}
'''
ONE_DUMP = f'''{EMPTY_DUMP}
--
-- Table structure for table `entity`
--
DROP TABLE IF EXISTS `entity`;
CREATE TABLE `entity` (
`uid` char(255) DEFAULT NULL,
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
--
-- Dumping data for table `entity`
--
LOCK TABLE `entity` WRITE;
INSERT INTO `entity` VALUES ('1337');
UNLOCK TABLES;
'''

MINI_DUMP = f'''{EMPTY_DUMP}
--
-- Table structure for table `entity`
--
DROP TABLE IF EXISTS `entity`;
CREATE TABLE `entity` (
`uid` char(255) DEFAULT NULL,
`value` char(255) DEFAULT NULL,
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
--
-- Dumping data for table `entity`
--
LOCK TABLE `entity` WRITE;
INSERT INTO `entity` VALUES ('101010','double');
UNLOCK TABLES;

--
-- Table structure for table `empty`
--
DROP TABLE IF EXISTS `empty`;
CREATE TABLE `empty` (
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
--
-- Dumping data for table `empty`
--
LOCK TABLE `empty` WRITE;
-- No data in table `empty`
UNLOCK TABLES;
'''


@pytest.fixture
def folder(tmp_path):
    folder = tmp_path / 'test_mysql'
    folder.mkdir()
    yield folder


@pytest.mark.parametrize(('db', 'content'), [
    (like_rilly_empty_db, EMPTY_DUMP),
    (as_good_as_empty_db, EMPTY_DUMP),
    (only_1_item_pea_db, ONE_DUMP),
    (mini_consistent_db, MINI_DUMP),
    ])
def test_serialize(folder, db, content):
    filename = str(folder / 'dump.sql')
    heimdall.serialize(db(), url=filename, format='sql:mysql')
    for root, dirs, files in folder.walk():
        assert len(files) == 1
        path = os.path.join(root, files[0])
        assert path == filename
        with open(path, 'r') as f:
            _content = f.read()
            print(_content)
            assert _content == content
